==> hermes-5.0.0.9.tar.gz: hermes-5.0.0.9/spec/apis/dmo/operations_spec.rb <==
require 'rails_helper'

module Hermes
  require [Hermes::Engine.root, %w[lib hermes tools specs]].flatten.join('/')

  ACCEPTABLE_PARAMS = %w[
    name
    code
    lessor_id
  ].freeze

  describe Api::Dmo::OperationsController, :type => :api do
    routes {Hermes::Engine.routes}
    include Devise::Test::ControllerHelpers
    include JwtAuthHelper
    let!(:responsible) { create(:user, roles: ['Administrator']) }
    let!(:user) { create(:user) }
    let!(:lessor) { create(:lessor, siret: '00000000000000', readers: [user.id.to_s]) }
    let!(:lessor2) { create(:lessor, siret: '00000000000000', readers: [responsible.id.to_s]) }
    
    let!(:operation1) { create(:operation, name: 'name1', lessor_id: lessor2.id.to_s) }
    let!(:operation2) { create(:operation, name: 'name2', lessor_id: lessor2.id.to_s) }
    let!(:operation3) { create(:operation, name: 'test3', lessor_id: lessor2.id.to_s) }
    let!(:operation4) { create(:operation, name: 'test4', lessor_id: lessor.id.to_s) }
    

    describe 'POST /operations' do
      describe 'Create as admin' do
        before :each do
          authenticated_header(request, responsible)
          post 'create', {
              data: {
                  attributes: {
                      name: 'test'
                  }
              }
          }
        end
        it 'returns status code 201' do

          expect(response).to have_http_status(201)
          expect(json['data']['attributes']['code']).to eq('ALSOP-4')
        end
      end

      describe 'Create as user without lessor_id' do
        before :each do
          authenticated_header(request, user)
          post 'create', {
              data: {
                  attributes: {
                      name: 'test',
                      code: 'Test'
                  }
              }
          }
        end
        it 'returns error when no lessor_id' do
          expect(response).to have_http_status(422)
        end
      end

      describe 'Create as user with lessor_id' do
        before :each do
          authenticated_header(request, user)
          post 'create', {
              data: {
                  attributes: {
                      name: 'test',
                      code: 'Bouh',
                      lessor_id: lessor.id.to_s
                  }
              }
          }
        end
        it 'returns 201' do
          expect(response).to have_http_status(201)
          expect(json['data']['attributes']['code']).to eq('BOUH')
        end
      end
    end

    describe 'GET /operations' do
      describe 'as admin' do 
        before :each do
          authenticated_header(request, responsible)
          get 'index'
        end
        it 'returns status code 200' do
          expect(response).to have_http_status(200)
        end
        it 'returns a valid json' do
          expect(json).not_to be_empty
          expect(json['data'].length).to eq(4)
        end
      end
      
      describe 'filter by lessor_id' do 
        before :each do
          authenticated_header(request, responsible)
          get 'index', {lessor_id: lessor2.id.to_s}
        end
        it 'returns status code 200' do
          expect(response).to have_http_status(200)
        end
        it 'returns a valid json' do
          expect(json).not_to be_empty
          expect(json['data'].length).to eq(3)
        end
      end

      describe 'regex on name' do 
        before :each do
          authenticated_header(request, responsible)
          get 'index', {name: {"$regex": "Tést" }}
        end
        it 'returns a valid json' do
          expect(response).to have_http_status(200)
          expect(json).not_to be_empty
          expect(json['data'].length).to eq(2)
        end
      end
      
      describe 'as user' do 
        before :each do
          authenticated_header(request, user)
          get 'index'
        end
        it 'returns status code 200' do
          expect(response).to have_http_status(200)
        end
        it 'returns a valid json' do
          expect(json).not_to be_empty
          expect(json['data'].length).to eq(1)
        end
      end
    end

    describe 'GET /operations/:id' do
      describe 'verif it work' do
        before :each do
          authenticated_header(request, user)
          get 'show', {id: operation4.id}
        end
        it 'returns status code 200' do
          expect(response).to have_http_status(200)
        end
        it 'returns a valid json' do
          expect(json).not_to be_empty
        end
      end

      describe 'verif it work not work with a non authorized user' do

        before :each do
          authenticated_header(request, user)
          get 'show', {id: operation1.id}
        end
        it 'returns status code 404' do
          expect(response).to have_http_status(404)
        end
      end
    end


    describe 'DELETE /operations/:id' do
      before :each do
        authenticated_header(request, responsible)

        delete 'destroy', {
            id: operation1.id.to_s
        }
      end
      it 'returns status code 204' do
        expect(response).to have_http_status(204)
      end
    end

  end
end

==> hermes-5.5.0.11.tar.gz: hermes-5.5.0.11/spec/apis/dmo/operations_spec.rb <==
require 'rails_helper'

module Hermes
  require [Hermes::Engine.root, %w[lib hermes tools specs]].flatten.join('/')

  ACCEPTABLE_PARAMS = %w[
    name
    code
    lessor_id
  ].freeze

  describe Api::Dmo::OperationsController, :type => :api do
    routes {Hermes::Engine.routes}
    include Devise::Test::ControllerHelpers
    include JwtAuthHelper
    let!(:responsible) { create(:user, roles: ['Administrator']) }
    let!(:user) { create(:user) }
    let!(:lessor) { create(:lessor, siret: '00000000000000', readers: [user.id.to_s]) }
    let!(:lessor2) { create(:lessor, siret: '00000000000000', readers: [responsible.id.to_s]) }
    
    let!(:operation1) { create(:operation, name: 'name1', lessor_id: lessor2.id.to_s) }
    let!(:operation2) { create(:operation, name: 'name2', lessor_id: lessor2.id.to_s) }
    let!(:operation3) { create(:operation, name: 'test3', lessor_id: lessor2.id.to_s) }
    let!(:operation4) { create(:operation, name: 'test4', lessor_id: lessor.id.to_s) }
    

    describe 'POST /operations' do
      describe 'Create as admin' do
        before :each do
          authenticated_header(request, responsible)
          post 'create', {
              data: {
                  attributes: {
                      name: 'test'
                  }
              }
          }
        end
        it 'returns status code 201' do

          expect(response).to have_http_status(201)
          expect(json['data']['attributes']['code']).to eq('ALSOP-4')
        end
      end

      describe 'Create as user without lessor_id' do
        before :each do
          authenticated_header(request, user)
          post 'create', {
              data: {
                  attributes: {
                      name: 'test',
                      code: 'Test'
                  }
              }
          }
        end
        it 'returns error when no lessor_id' do
          expect(response).to have_http_status(422)
        end
      end

      describe 'Create as user with lessor_id' do
        before :each do
          authenticated_header(request, user)
          post 'create', {
              data: {
                  attributes: {
                      name: 'test',
                      code: 'Bouh',
                      lessor_id: lessor.id.to_s
                  }
              }
          }
        end
        it 'returns 201' do
          expect(response).to have_http_status(201)
          expect(json['data']['attributes']['code']).to eq('BOUH')
        end
      end
    end

    describe 'GET /operations' do
      describe 'as admin' do 
        before :each do
          authenticated_header(request, responsible)
          get 'index'
        end
        it 'returns status code 200' do
          expect(response).to have_http_status(200)
        end
        it 'returns a valid json' do
          expect(json).not_to be_empty
          expect(json['data'].length).to eq(4)
        end
      end
      
      describe 'filter by lessor_id' do 
        before :each do
          authenticated_header(request, responsible)
          get 'index', {lessor_id: lessor2.id.to_s}
        end
        it 'returns status code 200' do
          expect(response).to have_http_status(200)
        end
        it 'returns a valid json' do
          expect(json).not_to be_empty
          expect(json['data'].length).to eq(3)
        end
      end

      describe 'regex on name' do 
        before :each do
          authenticated_header(request, responsible)
          get 'index', {name: {"$regex": "éSt" }}
        end
        it 'returns a valid json' do
          expect(response).to have_http_status(200)
          expect(json).not_to be_empty
          expect(json['data'].length).to eq(2)
        end
      end
      
      describe 'as user' do 
        before :each do
          authenticated_header(request, user)
          get 'index'
        end
        it 'returns status code 200' do
          expect(response).to have_http_status(200)
        end
        it 'returns a valid json' do
          expect(json).not_to be_empty
          expect(json['data'].length).to eq(1)
        end
      end
    end

    describe 'GET /operations/:id' do
      describe 'verif it work' do
        before :each do
          authenticated_header(request, user)
          get 'show', {id: operation4.id}
        end
        it 'returns status code 200' do
          expect(response).to have_http_status(200)
        end
        it 'returns a valid json' do
          expect(json).not_to be_empty
        end
      end

      describe 'verif it work not work with a non authorized user' do

        before :each do
          authenticated_header(request, user)
          get 'show', {id: operation1.id}
        end
        it 'returns status code 404' do
          expect(response).to have_http_status(404)
        end
      end
    end


    describe 'DELETE /operations/:id' do
      before :each do
        authenticated_header(request, responsible)

        delete 'destroy', {
            id: operation1.id.to_s
        }
      end
      it 'returns status code 204' do
        expect(response).to have_http_status(204)
      end
    end

  end
end
